==> zio-aws-route53resolver_3-5.17.104.3-sources.jar: zio/aws/route53resolver/model/DisassociateResolverEndpointIpAddressResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DisassociateResolverEndpointIpAddressResponse(
    resolverEndpoint: Option[zio.aws.route53resolver.model.ResolverEndpoint] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse = {
    import DisassociateResolverEndpointIpAddressResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
      .builder()
      .optionallyWith(resolverEndpoint.map(value => value.buildAwsValue()))(
        _.resolverEndpoint
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
      .wrap(buildAwsValue())
}
object DisassociateResolverEndpointIpAddressResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse =
      zio.aws.route53resolver.model
        .DisassociateResolverEndpointIpAddressResponse(
          resolverEndpoint.map(value => value.asEditable)
        )
    def resolverEndpoint
        : Option[zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly]
    def getResolverEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly
    ] = AwsError.unwrapOptionField("resolverEndpoint", resolverEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ) extends zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly {
    override val resolverEndpoint
        : Option[zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly] =
      scala
        .Option(impl.resolverEndpoint())
        .map(value =>
          zio.aws.route53resolver.model.ResolverEndpoint.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ): zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_3-5.17.164.1-sources.jar: zio/aws/route53resolver/model/DisassociateResolverEndpointIpAddressResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisassociateResolverEndpointIpAddressResponse(
    resolverEndpoint: Optional[zio.aws.route53resolver.model.ResolverEndpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse = {
    import DisassociateResolverEndpointIpAddressResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
      .builder()
      .optionallyWith(resolverEndpoint.map(value => value.buildAwsValue()))(
        _.resolverEndpoint
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
      .wrap(buildAwsValue())
}
object DisassociateResolverEndpointIpAddressResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse =
      zio.aws.route53resolver.model
        .DisassociateResolverEndpointIpAddressResponse(
          resolverEndpoint.map(value => value.asEditable)
        )
    def resolverEndpoint
        : Optional[zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly]
    def getResolverEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly
    ] = AwsError.unwrapOptionField("resolverEndpoint", resolverEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ) extends zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly {
    override val resolverEndpoint
        : Optional[zio.aws.route53resolver.model.ResolverEndpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resolverEndpoint())
        .map(value =>
          zio.aws.route53resolver.model.ResolverEndpoint.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverEndpointIpAddressResponse
  ): zio.aws.route53resolver.model.DisassociateResolverEndpointIpAddressResponse.ReadOnly =
    new Wrapper(impl)
}
